# OIDCProxyDomainMapping

The mappings between internal domain names and external domain names.
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**primary_external_name** | **str** | The primary external name is the name that gets exposed publicly. | 
**primary_internal_name** | **str** | The primary internal name is the name that used internally in the local environment. | 
**other_mappings** | [**list[OIDCProxyDomainNameMapping]**](OIDCProxyDomainNameMapping.md) | The list of extra mappings between internal and external domain names. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


